/* Please see the LICENSE file for copyright and distribution information */

#ifndef __RUBY_LIBXML_H__
#define __RUBY_LIBXML_H__

#include <ruby.h>
#include <libxml/xmlversion.h>

#include "ruby_xml_version.h"
#include "ruby_xml.h"
#include "ruby_xml_io.h"
#include "ruby_xml_error.h"
#include "ruby_xml_encoding.h"
#include "ruby_xml_attributes.h"
#include "ruby_xml_attr.h"
#include "ruby_xml_attr_decl.h"
#include "ruby_xml_document.h"
#include "ruby_xml_node.h"
#include "ruby_xml_namespace.h"
#include "ruby_xml_namespaces.h"
#include "ruby_xml_parser.h"
#include "ruby_xml_parser_options.h"
#include "ruby_xml_parser_context.h"
#include "ruby_xml_html_parser.h"
#include "ruby_xml_html_parser_options.h"
#include "ruby_xml_html_parser_context.h"
#include "ruby_xml_reader.h"
#include "ruby_xml_writer.h"
#include "ruby_xml_sax2_handler.h"
#include "ruby_xml_sax_parser.h"
#include "ruby_xml_writer.h"
#include "ruby_xml_xinclude.h"
#include "ruby_xml_xpath.h"
#include "ruby_xml_xpath_expression.h"
#include "ruby_xml_xpath_context.h"
#include "ruby_xml_xpath_object.h"
#include "ruby_xml_xpointer.h"
#include "ruby_xml_input_cbg.h"
#include "ruby_xml_dtd.h"
#include "ruby_xml_schema.h"
#include "ruby_xml_relaxng.h"

extern VALUE mLibXML;

#endif
